@@ -1,4 +1,12 @@
-
+#  File R/transmissionTimeline.R in package ndtv, part of the Statnet suite
+#  of packages for network analysis, http://statnet.org .
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) at
+#  http://statnet.org/attribution
+#
+#  Copyright 2016 Statnet Commons
+#######################################################################
 
 
 transmissionTimeline<-function(x,time.attr,
@@ -63,7 +71,8 @@ transmissionTimeline<-function(x,time.attr,
   }
   #op <- par(no.readonly = TRUE)
   if(jitter){
-    coords<-jitter(coords)
+    # only consider the coordinates with finite values when computing jitter
+    coords[is.finite(coords)]<-jitter(coords[is.finite(coords)])
   }
   # set up the plotting window
   plot(coords,pch=NA,xlab=xlab,ylab=ylab,...)
